@@ -2,12 +2,12 @@ package Locale::TextDomain::OO::Lexicon::StoreJSON; ## no critic (TidyCode)
 
 use strict;
 use warnings;
-use JSON -support_by_pp, -no_export;
+use JSON::PP ();
 use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.021';
+our $VERSION = '1.022';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::StoreFile
@@ -18,7 +18,7 @@ sub to_json {
     my $self = shift;
 
     return $self->store_content(
-        JSON ## no critic (LongChainsOfMethodCalls)
+        JSON::PP ## no critic (LongChainsOfMethodCalls)
             ->new
             ->utf8
             ->sort_by( sub { $JSON::PP::a cmp $JSON::PP::b } ) ## no critic (PackageVars)
@@ -54,13 +54,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::StoreJSON - Stores the lexicon for other programming languages
 
-$Id: StoreJSON.pm 608 2015-08-10 06:16:36Z steffenw $
+$Id: StoreJSON.pm 611 2015-08-10 07:12:05Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/StoreJSON.pm $
 
 =head1 VERSION
 
-1.021
+1.022
 
 =head1 DESCRIPTION
 
