@@ -10,7 +10,7 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Str);
 use namespace::autoclean;
 
-our $VERSION = '1.019';
+our $VERSION = '1.024';
 
 with qw(
     Locale::TextDomain::OO::Role::Logger
@@ -133,7 +133,7 @@ my $unescape_maketext = sub {
 };
 
 sub translate { ## no critic (ExcessComplexity ManyArgs)
-    my ($self, $msgctxt, $msgid, $msgid_plural, $count, $is_n) = @_;
+    my ($self, $msgctxt, $msgid, $msgid_plural, $count, $is_n, $plural_callback) = @_;
 
     my $key_util = Locale::TextDomain::OO::Util::JoinSplitLexiconKeys->instance;
     my $lexicon_key = $key_util->join_lexicon_key({(
@@ -159,7 +159,13 @@ sub translate { ## no critic (ExcessComplexity ManyArgs)
             msgid_plural => $escape_maketext->($msgid_plural),
         });
     };
-    if ( $is_n ) {
+    if ( $plural_callback ) {
+        $plural_callback->(
+            $lexicon->{ q{} }->{plural_code}
+            || confess qq{Plural-Forms not found in lexicon "$lexicon_key"},
+        );
+    }
+    elsif ( $is_n ) {
         my $plural_code = $lexicon->{ q{} }->{plural_code}
             or confess qq{Plural-Forms not found in lexicon "$lexicon_key"};
         my $multiplural_index = ref $count eq 'ARRAY'
@@ -254,7 +260,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.019
+1.024
 
 =head1 DESCRIPTION
 
